.. _contributing:

Contributing
============

There are dozens of ways to contribute to Weblate. We welcome any help, be it
coding help, graphics design, documentation or sponsorship.

Code and development
--------------------

Weblate is being developed on GitHub <https://github.com/nijel/weblate>. You
are welcome to fork the code and open pull requests. Patches in any other form
are welcome as well. The code should follow PEP-8 coding guidelines.

We do write testsuite for our code, so please add testcases for any new
functionality and verify that it works. You can see current test results on
Travis <https://travis-ci.org/nijel/weblate> and coverage on Codecov
<https://codecov.io/github/nijel/weblate>.

The issue tracker is hosted on GitHub as well:
<https://github.com/nijel/weblate/issues>

Starting with our codebase
--------------------------

If you are looking for some bugs which should be good for starting with our
codebase, you can find them labelled with :guilabel:`newbie` tag:

https://github.com/nijel/weblate/labels/newbie

Earning money by coding
-----------------------

We're using Bountysource to fund our development, you can participate on this
as well by implementing issues with bounties:

https://github.com/nijel/weblate/labels/bounty

Translating
-----------

Weblate is being translated using Weblate on <https://hosted.weblate.org/>, feel
free to join us in effort to make Weblate available in as many world languages
as possible.
